#!/bin/bash

VERSION=2.3
XSLBASE=../${VERSION}
NOSTOP=$1

check() {
  diff $1 $2 2>>/dev/null >>/dev/null
  if [ $? -ne 0 ]; then
    echo "ERROR";
    echo "diff $1 $2";
    if [ ! $NOSTOP ]; then
      exit
    fi
  fi
}

dotest() {
  xml="$1"
  dir="$2"
  shift 2
  out="${dir}.out"
  if [ -d "$out" ]; then rm -rf "$out"; fi
  mkdir "$out"

  echo "${xml}.xml"
  xsltproc $* --output "${out}/${xml}.html" "${XSLBASE}/tohtml.xsl" "${xml}.xml"
  check "${dir}.ref/${xml}.html" "${out}/${xml}.html"

  xsltproc $* --param with-ids 1 --output "${out}/${xml}_id.html" "${XSLBASE}/tohtml.xsl" "${xml}.xml"
  check "${dir}.ref/${xml}_id.html" "${out}/${xml}_id.html"

  xsltproc $* --output "${out}/${xml}.php" "${XSLBASE}/tophp.xsl" "${xml}.xml"
  check "${dir}.ref/${xml}.php" "${out}/${xml}.php"

  xsltproc $* --output "${out}/${xml}_csv.php" "${XSLBASE}/tocsv.xsl" "${xml}.xml"
  check "${dir}.ref/${xml}_csv.php" "${out}/${xml}_csv.php"

  xsltproc $* --output "${out}/${xml}.sql" "${XSLBASE}/tosql.xsl" "${xml}.xml"
  check "${dir}.ref/${xml}.sql" "${out}/${xml}.sql"

  xsltproc $* --output "${out}/${xml}_stat.php" "${XSLBASE}/tostat.xsl" "${xml}.xml"
  check "${dir}.ref/${xml}_stat.php" "${out}/${xml}_stat.php"

  xsltproc $* --output "${out}/${xml}_id.php" "${XSLBASE}/toids.xsl" "${xml}.xml"
  check "${dir}.ref/${xml}_id.php" "${out}/${xml}_id.php"
  echo
}

# dotest dateiname(.xml) verzeichnis parameter
dotest basis basis
dotest basis basis_with --param with-time 1 --param with-ip 1 --param with-user 1 --param with-fnum 1 --param with-dbcreate 0 --param with-dbgrant 0
dotest fixid fixid
dotest stats stats
dotest txtselect txtselect
dotest sections sections
dotest values values
dotest restrict_url restrict_url
dotest restrict_inline restrict_inline
dotest restrict_inline_short restrict_inline_short
dotest restrict_user restrict_user
dotest params params --stringparam title paramtitel --stringparam css-stylesheet paramstyle.css --stringparam baseurl parambase --stringparam submiturl paramurl --stringparam db_table parampoll --stringparam db_name paramdb --stringparam db_user paramuser --stringparam db_pass parampass --stringparam db_host paramhost

echo "Success!"
